import {FC, useEffect, useState} from "react";
import {View} from "@tarojs/components";
import styles from './index.module.scss'
import {VideoList} from "@/pages/index/components/videoList";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";
import {CoursesKey, publicApi} from "@/api/public";
import NavigationBar from "@/components/navigationBar/navigationBar";
// import Taro from "@tarojs/taro";

const category: TabList[] = [
  {title: "企选课程", value: 'is_required'},
  {title: "平台课程", value: 'is_not_required'},
]

const Index: FC = () => {
  const [categoryKey, setCategoryKey] = useState<CoursesKey>('is_required')

  function tabChange(data: OnChangOpt) {
    setCategoryKey(data.tab?.value as CoursesKey)
  }

  return (
    <View className={styles.content}>
      <NavigationBar
        cancelBack
        leftNode={<Tabs tabList={category} onChange={tabChange} current={categoryKey}/>}
        backgroundColor={'transparent'}
      />
      <VideoList
        categoryKey={categoryKey}
        setCategoryKey={(categoryKey) => setCategoryKey(categoryKey)}
      />
    </View>
  )
}

const AuditMode: FC = () => {
  const [auditMode, setAuditMode] = useState(false)
  const [articles, setArticles] = useState<any[]>([])
  useEffect(() => {
    publicApi.course({page: 1, pageSize: 10}).then(res => {
      setAuditMode(res.audit_mode)
      setArticles(res.articles)
      // if(res.audit_mode){
      //   Taro.setTabBarItem({index: 1, text: '文章'})
      // }
    })
  }, [])
  return (
    <>
      {
        auditMode ?
          <>
            <NavigationBar text='文章' cancelBack/>
            <View className='p-2'>
              {
                articles.map(d => <View className='mb-2 p-2 bg-white'>{d.title}</View>)
              }
            </View>
          </>
          : <Index/>
      }
    </>
  )
}

export default AuditMode
